@@ -2,11 +2,11 @@
 
 rm -rf config.cache build
 mkdir build
-libtoolize --force
+libtoolize --force $LIBTOOLIZE_FLAGS
 aclocal -I m4
 autoconf
 autoheader
-automake --add-missing
+automake --add-missing $AUTOMAKE_FLAGS
 
 if test x$NOCONFIGURE = x; then
 	echo "./configure $*"
