@@ -33,6 +33,7 @@
 #include <mpd/directory.h>
 #include <mpd/pair.h>
 #include "uri.h"
+#include "iso8601.h"
 
 #include <assert.h>
 #include <stdlib.h>
@@ -45,6 +46,12 @@ struct mpd_directory {
 	 * slash.
 	 */
 	char *path;
+
+	/**
+	 * The POSIX UTC time stamp of the last modification, or 0 if
+	 * that is unknown.
+	 */
+	time_t last_modified;
 };
 
 mpd_malloc
@@ -68,6 +75,8 @@ mpd_directory_new(const char *path)
 		return NULL;
 	}
 
+	directory->last_modified = 0;
+
 	return directory;
 }
 
@@ -86,7 +95,9 @@ mpd_directory_dup(const struct mpd_directory *directory)
 	assert(directory != NULL);
 	assert(directory->path != NULL);
 
-	return mpd_directory_new(directory->path);
+	struct mpd_directory *copy = mpd_directory_new(directory->path);
+	copy->last_modified = directory->last_modified;
+	return copy;
 }
 
 const char *
@@ -98,6 +109,14 @@ mpd_directory_get_path(const struct mpd_directory *directory)
 	return directory->path;
 }
 
+time_t
+mpd_directory_get_last_modified(const struct mpd_directory *directory)
+{
+	assert(directory != NULL);
+
+	return directory->last_modified;
+}
+
 struct mpd_directory *
 mpd_directory_begin(const struct mpd_pair *pair)
 {
@@ -125,10 +144,9 @@ mpd_directory_feed(struct mpd_directory *directory,
 	if (strcmp(pair->name, "directory") == 0)
 		return false;
 
-	/* ignore all other pairs - that might be attributes which we
-	   don't support yet */
-
-	(void)directory;
+	if (strcmp(pair->name, "Last-Modified") == 0)
+		directory->last_modified =
+			iso8601_datetime_parse(pair->value);
 
 	return true;
 }
