@@ -35,12 +35,24 @@
 #include <mpd/entity.h>
 #include <mpd/search.h>
 #include <mpd/tag.h>
+#include <mpd/message.h>
 
+#include <assert.h>
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
 
+static int
+handle_error(struct mpd_connection *c)
+{
+	assert(mpd_connection_get_error(c) != MPD_ERROR_SUCCESS);
+
+	fprintf(stderr, "%s\n", mpd_connection_get_error_message(c));
+	mpd_connection_free(c);
+	return EXIT_FAILURE;
+}
+
 static void
 print_tag(const struct mpd_song *song, enum mpd_tag_type type,
 	  const char *label)
@@ -57,11 +69,8 @@ int main(int argc, char ** argv) {
 
 	conn = mpd_connection_new(NULL, 0, 30000);
 
-	if (mpd_connection_get_error(conn) != MPD_ERROR_SUCCESS) {
-		fprintf(stderr,"%s\n", mpd_connection_get_error_message(conn));
-		mpd_connection_free(conn);
-		return -1;
-	}
+	if (mpd_connection_get_error(conn) != MPD_ERROR_SUCCESS)
+		return handle_error(conn);
 
 	{
 		int i;
@@ -82,11 +91,8 @@ int main(int argc, char ** argv) {
 		mpd_command_list_end(conn);
 
 		status = mpd_recv_status(conn);
-		if (status == NULL) {
-			fprintf(stderr,"%s\n", mpd_connection_get_error_message(conn));
-			mpd_connection_free(conn);
-			return -1;
-		}
+		if (status == NULL)
+			return handle_error(conn);
 
 		printf("volume: %i\n", mpd_status_get_volume(status));
 		printf("repeat: %i\n", mpd_status_get_repeat(status));
@@ -111,11 +117,10 @@ int main(int argc, char ** argv) {
 			printf("channels: %i\n", audio_format->channels);
 		}
 
-		if (mpd_connection_get_error(conn) != MPD_ERROR_SUCCESS) {
-			fprintf(stderr,"%s\n", mpd_connection_get_error_message(conn));
-			mpd_connection_free(conn);
-			return -1;
-		}
+		mpd_status_free(status);
+
+		if (mpd_connection_get_error(conn) != MPD_ERROR_SUCCESS)
+			return handle_error(conn);
 
 		mpd_response_next(conn);
 
@@ -137,28 +142,15 @@ int main(int argc, char ** argv) {
 			mpd_song_free(song);
 		}
 
-		if (mpd_connection_get_error(conn) != MPD_ERROR_SUCCESS) {
-			fprintf(stderr,"%s\n", mpd_connection_get_error_message(conn));
-			mpd_connection_free(conn);
-			return -1;
-		}
-
-		if (!mpd_response_finish(conn)) {
-			fprintf(stderr,"%s\n", mpd_connection_get_error_message(conn));
-			mpd_connection_free(conn);
-			return -1;
-		}
-	
-		mpd_status_free(status);
+		if (mpd_connection_get_error(conn) != MPD_ERROR_SUCCESS ||
+		    !mpd_response_finish(conn))
+			return handle_error(conn);
 	}
 	else if(argc==3 && strcmp(argv[1],"lsinfo")==0) {
 		struct mpd_entity * entity;
 
-		if (!mpd_send_list_meta(conn,argv[2])) {
-			fprintf(stderr,"%s\n", mpd_connection_get_error_message(conn));
-			mpd_connection_free(conn);
-			return -1;
-		}
+		if (!mpd_send_list_meta(conn, argv[2]))
+			return handle_error(conn);
 
 		while ((entity = mpd_recv_entity(conn)) != NULL) {
 			const struct mpd_song *song;
@@ -193,28 +185,16 @@ int main(int argc, char ** argv) {
 			mpd_entity_free(entity);
 		}
 
-		if (mpd_connection_get_error(conn) != MPD_ERROR_SUCCESS) {
-			fprintf(stderr, "%s\n",
-				mpd_connection_get_error_message(conn));
-			mpd_connection_free(conn);
-			return -1;
-		}
-
-		if (!mpd_response_finish(conn)) {
-			fprintf(stderr, "%s\n", mpd_connection_get_error_message(conn));
-			mpd_connection_free(conn);
-			return -1;
-		}
+		if (mpd_connection_get_error(conn) != MPD_ERROR_SUCCESS ||
+		    !mpd_response_finish(conn))
+			return handle_error(conn);
 	}
 	else if(argc==2 && strcmp(argv[1],"artists")==0) {
 		struct mpd_pair *pair;
-	
+
 		if (!mpd_search_db_tags(conn, MPD_TAG_ARTIST) ||
-		    !mpd_search_commit(conn)) {
-			fprintf(stderr,"%s\n", mpd_connection_get_error_message(conn));
-			mpd_connection_free(conn);
-			return -1;
-		}
+		    !mpd_search_commit(conn))
+			return handle_error(conn);
 
 		while ((pair = mpd_recv_pair_tag(conn,
 						 MPD_TAG_ARTIST)) != NULL) {
@@ -222,17 +202,81 @@ int main(int argc, char ** argv) {
 			mpd_return_pair(conn, pair);
 		}
 
-		if (mpd_connection_get_error(conn) != MPD_ERROR_SUCCESS) {
-			fprintf(stderr,"%s\n", mpd_connection_get_error_message(conn));
-			mpd_connection_free(conn);
-			return -1;
+		if (mpd_connection_get_error(conn) != MPD_ERROR_SUCCESS ||
+		    !mpd_response_finish(conn))
+			return handle_error(conn);
+	} else if (argc == 2 && strcmp(argv[1], "playlists") == 0) {
+		if (!mpd_send_list_playlists(conn))
+			return handle_error(conn);
+
+		struct mpd_playlist *playlist;
+		while ((playlist = mpd_recv_playlist(conn)) != NULL) {
+			printf("%s\n",
+			       mpd_playlist_get_path(playlist));
+			mpd_playlist_free(playlist);
 		}
 
-		if (!mpd_response_finish(conn)) {
-			fprintf(stderr,"%s\n", mpd_connection_get_error_message(conn));
-			mpd_connection_free(conn);
-			return -1;
+		if (mpd_connection_get_error(conn) != MPD_ERROR_SUCCESS ||
+		    !mpd_response_finish(conn))
+			return handle_error(conn);
+	} else if (argc == 2 && strcmp(argv[1], "idle") == 0) {
+		enum mpd_idle idle = mpd_run_idle(conn);
+		if (idle == 0 &&
+		    mpd_connection_get_error(conn) != MPD_ERROR_SUCCESS)
+			return handle_error(conn);
+
+		for (unsigned j = 0;; ++j) {
+			enum mpd_idle i = 1 << j;
+			const char *name = mpd_idle_name(i);
+
+			if (name == NULL)
+				break;
+
+			if (idle & i)
+				printf("%s\n", name);
 		}
+	} else if (argc == 3 && strcmp(argv[1], "subscribe") == 0) {
+		/* subscribe to a channel and print all messages */
+
+		if (!mpd_run_subscribe(conn, argv[2]))
+			return handle_error(conn);
+
+		while (mpd_run_idle_mask(conn, MPD_IDLE_MESSAGE) != 0) {
+			if (!mpd_send_read_messages(conn))
+				return handle_error(conn);
+
+			struct mpd_message *msg;
+			while ((msg = mpd_recv_message(conn)) != NULL) {
+				printf("%s\n", mpd_message_get_text(msg));
+				mpd_message_free(msg);
+			}
+
+			if (mpd_connection_get_error(conn) != MPD_ERROR_SUCCESS ||
+			    !mpd_response_finish(conn))
+				return handle_error(conn);
+		}
+
+		return handle_error(conn);
+	} else if (argc == 2 && strcmp(argv[1], "channels") == 0) {
+		/* print a list of channels */
+
+		if (!mpd_send_channels(conn))
+			return handle_error(conn);
+
+		struct mpd_pair *pair;
+		while ((pair = mpd_recv_channel_pair(conn)) != NULL) {
+			printf("%s\n", pair->value);
+			mpd_return_pair(conn, pair);
+		}
+
+		if (mpd_connection_get_error(conn) != MPD_ERROR_SUCCESS ||
+		    !mpd_response_finish(conn))
+			return handle_error(conn);
+	} else if (argc == 4 && strcmp(argv[1], "message") == 0) {
+		/* send a message to a channel */
+
+		if (!mpd_run_send_message(conn, argv[2], argv[3]))
+			return handle_error(conn);
 	}
 
 	mpd_connection_free(conn);
