@@ -70,6 +70,8 @@ mpd_playlist_new(const char *path)
 		return NULL;
 	}
 
+	playlist->last_modified = 0;
+
 	return playlist;
 }
 
@@ -89,7 +91,9 @@ mpd_playlist_dup(const struct mpd_playlist *playlist)
 	assert(playlist != NULL);
 	assert(playlist->path != NULL);
 
-	return mpd_playlist_new(playlist->path);
+	struct mpd_playlist *copy = mpd_playlist_new(playlist->path);
+	copy->last_modified = playlist->last_modified;
+	return copy;
 }
 
 const char *
