@@ -42,6 +42,16 @@ enum {
 	LONGLONGLEN = (sizeof(long long) * CHAR_BIT + 1) / 3 + 1,
 };
 
+static void
+format_range(char *buffer, size_t size, unsigned start, unsigned end)
+{
+	if (end == (unsigned)-1)
+		/* the special value -1 means "open end" */
+		snprintf(buffer, size, "%u:", start);
+	else
+		snprintf(buffer, size, "%u:%u", start, end);
+}
+
 /**
  * Checks whether it is possible to send a command now.
  */
@@ -140,6 +150,19 @@ mpd_send_int2_command(struct mpd_connection *connection, const char *command,
 				arg1_string, arg2_string, NULL);
 }
 
+bool
+mpd_send_int3_command(struct mpd_connection *connection, const char *command,
+		      int arg1, int arg2, int arg3)
+{
+	char arg1_string[INTLEN], arg2_string[INTLEN], arg3_string[INTLEN];
+
+	snprintf(arg1_string, sizeof(arg1_string), "%i", arg1);
+	snprintf(arg2_string, sizeof(arg2_string), "%i", arg2);
+	snprintf(arg3_string, sizeof(arg3_string), "%i", arg3);
+	return mpd_send_command(connection, command,
+				arg1_string, arg2_string, arg3_string, NULL);
+}
+
 bool
 mpd_send_float_command(struct mpd_connection *connection, const char *command,
 		       float arg)
@@ -167,10 +190,23 @@ mpd_send_range_command(struct mpd_connection *connection, const char *command,
 {
 	char arg_string[INTLEN*2+1];
 
-	snprintf(arg_string, sizeof arg_string, "%u:%u", arg1, arg2);
+	format_range(arg_string, sizeof(arg_string), arg1, arg2);
 	return mpd_send_command(connection, command, arg_string, NULL);
 }
 
+bool
+mpd_send_i_range_command(struct mpd_connection *connection,
+			 const char *command, int arg1,
+			 unsigned start, unsigned end)
+{
+	char arg1_string[INTLEN + 1], arg2_string[INTLEN * 2 + 1];
+
+	snprintf(arg1_string, sizeof(arg1_string), "%i", arg1);
+	format_range(arg2_string, sizeof(arg2_string), start, end);
+	return mpd_send_command(connection, command,
+				arg1_string, arg2_string, NULL);
+}
+
 bool
 mpd_send_range_u_command(struct mpd_connection *connection,
 			 const char *command,
@@ -178,7 +214,7 @@ mpd_send_range_u_command(struct mpd_connection *connection,
 {
 	char arg1_string[INTLEN*2+1], arg2_string[INTLEN];
 
-	snprintf(arg1_string, sizeof arg1_string, "%u:%u", start, end);
+	format_range(arg1_string, sizeof(arg1_string), start, end);
 	snprintf(arg2_string, sizeof(arg2_string), "%i", arg2);
 	return mpd_send_command(connection, command,
 				arg1_string, arg2_string, NULL);
@@ -190,7 +226,11 @@ mpd_send_ll_command(struct mpd_connection *connection, const char *command,
 {
 	char arg_string[LONGLONGLEN];
 
+#ifdef WIN32
+	snprintf(arg_string, sizeof(arg_string), "%ld", (long)arg);
+#else
 	snprintf(arg_string, sizeof(arg_string), "%lld", arg);
+#endif
 	return mpd_send_command(connection, command, arg_string, NULL);
 }
 
